# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/generic_proxy/v3/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.type.matcher.v3 import matcher_pb2 as xds_dot_type_dot_matcher_dot_v3_dot_matcher__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=envoy/extensions/filters/network/generic_proxy/v3/route.proto\x12\x31\x65nvoy.extensions.filters.network.generic_proxy.v3\x1a\x1fxds/annotations/v3/status.proto\x1a!xds/type/matcher/v3/matcher.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"u\n\x0bVirtualHost\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x05hosts\x18\x02 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x36\n\x06routes\x18\x03 \x01(\x0b\x32\x1c.xds.type.matcher.v3.MatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xb0\x01\n\x12RouteConfiguration\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x06routes\x18\x02 \x01(\x0b\x32\x1c.xds.type.matcher.v3.Matcher\x12U\n\rvirtual_hosts\x18\x03 \x03(\x0b\x32>.envoy.extensions.filters.network.generic_proxy.v3.VirtualHostB\xc9\x01\n?io.envoyproxy.envoy.extensions.filters.network.generic_proxy.v3B\nRouteProtoP\x01Zhgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/generic_proxy/v3;generic_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.generic_proxy.v3.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.extensions.filters.network.generic_proxy.v3B\nRouteProtoP\001Zhgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/generic_proxy/v3;generic_proxyv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _VIRTUALHOST.fields_by_name['name']._options = None
  _VIRTUALHOST.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _VIRTUALHOST.fields_by_name['hosts']._options = None
  _VIRTUALHOST.fields_by_name['hosts']._serialized_options = b'\372B\005\222\001\002\010\001'
  _VIRTUALHOST.fields_by_name['routes']._options = None
  _VIRTUALHOST.fields_by_name['routes']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTECONFIGURATION.fields_by_name['name']._options = None
  _ROUTECONFIGURATION.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_VIRTUALHOST']._serialized_start=240
  _globals['_VIRTUALHOST']._serialized_end=357
  _globals['_ROUTECONFIGURATION']._serialized_start=360
  _globals['_ROUTECONFIGURATION']._serialized_end=536
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/cluster/v3/outlier_detection_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3envoy/data/cluster/v3/outlier_detection_event.proto\x12\x15\x65nvoy.data.cluster.v3\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb6\x05\n\x15OutlierDetectionEvent\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32*.envoy.data.cluster.v3.OutlierEjectionTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x16secs_since_last_action\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1d\n\x0c\x63luster_name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1d\n\x0cupstream_url\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x37\n\x06\x61\x63tion\x18\x06 \x01(\x0e\x32\x1d.envoy.data.cluster.v3.ActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rnum_ejections\x18\x07 \x01(\r\x12\x10\n\x08\x65nforced\x18\x08 \x01(\x08\x12R\n\x18\x65ject_success_rate_event\x18\t \x01(\x0b\x32..envoy.data.cluster.v3.OutlierEjectSuccessRateH\x00\x12Q\n\x17\x65ject_consecutive_event\x18\n \x01(\x0b\x32..envoy.data.cluster.v3.OutlierEjectConsecutiveH\x00\x12^\n\x1e\x65ject_failure_percentage_event\x18\x0b \x01(\x0b\x32\x34.envoy.data.cluster.v3.OutlierEjectFailurePercentageH\x00:7\x9a\xc5\x88\x1e\x32\n0envoy.data.cluster.v2alpha.OutlierDetectionEventB\x0c\n\x05\x65vent\x12\x03\xf8\x42\x01\"\xe1\x01\n\x17OutlierEjectSuccessRate\x12\"\n\x11host_success_rate\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\x12-\n\x1c\x63luster_average_success_rate\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\x12\x38\n\'cluster_success_rate_ejection_threshold\x18\x03 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64:9\x9a\xc5\x88\x1e\x34\n2envoy.data.cluster.v2alpha.OutlierEjectSuccessRate\"T\n\x17OutlierEjectConsecutive:9\x9a\xc5\x88\x1e\x34\n2envoy.data.cluster.v2alpha.OutlierEjectConsecutive\"\x84\x01\n\x1dOutlierEjectFailurePercentage\x12\"\n\x11host_success_rate\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64:?\x9a\xc5\x88\x1e:\n8envoy.data.cluster.v2alpha.OutlierEjectFailurePercentage*\xdf\x01\n\x13OutlierEjectionType\x12\x13\n\x0f\x43ONSECUTIVE_5XX\x10\x00\x12\x1f\n\x1b\x43ONSECUTIVE_GATEWAY_FAILURE\x10\x01\x12\x10\n\x0cSUCCESS_RATE\x10\x02\x12$\n CONSECUTIVE_LOCAL_ORIGIN_FAILURE\x10\x03\x12\x1d\n\x19SUCCESS_RATE_LOCAL_ORIGIN\x10\x04\x12\x16\n\x12\x46\x41ILURE_PERCENTAGE\x10\x05\x12#\n\x1f\x46\x41ILURE_PERCENTAGE_LOCAL_ORIGIN\x10\x06* \n\x06\x41\x63tion\x12\t\n\x05\x45JECT\x10\x00\x12\x0b\n\x07UNEJECT\x10\x01\x42\x93\x01\n#io.envoyproxy.envoy.data.cluster.v3B\x1aOutlierDetectionEventProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/data/cluster/v3;clusterv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.cluster.v3.outlier_detection_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.data.cluster.v3B\032OutlierDetectionEventProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/data/cluster/v3;clusterv3\272\200\310\321\006\002\020\002'
  _OUTLIERDETECTIONEVENT.oneofs_by_name['event']._options = None
  _OUTLIERDETECTIONEVENT.oneofs_by_name['event']._serialized_options = b'\370B\001'
  _OUTLIERDETECTIONEVENT.fields_by_name['type']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _OUTLIERDETECTIONEVENT.fields_by_name['cluster_name']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002\020\001'
  _OUTLIERDETECTIONEVENT.fields_by_name['upstream_url']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['upstream_url']._serialized_options = b'\372B\004r\002\020\001'
  _OUTLIERDETECTIONEVENT.fields_by_name['action']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['action']._serialized_options = b'\372B\005\202\001\002\020\001'
  _OUTLIERDETECTIONEVENT._options = None
  _OUTLIERDETECTIONEVENT._serialized_options = b'\232\305\210\0362\n0envoy.data.cluster.v2alpha.OutlierDetectionEvent'
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['host_success_rate']._options = None
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['host_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_average_success_rate']._options = None
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_average_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_success_rate_ejection_threshold']._options = None
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_success_rate_ejection_threshold']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTSUCCESSRATE._options = None
  _OUTLIEREJECTSUCCESSRATE._serialized_options = b'\232\305\210\0364\n2envoy.data.cluster.v2alpha.OutlierEjectSuccessRate'
  _OUTLIEREJECTCONSECUTIVE._options = None
  _OUTLIEREJECTCONSECUTIVE._serialized_options = b'\232\305\210\0364\n2envoy.data.cluster.v2alpha.OutlierEjectConsecutive'
  _OUTLIEREJECTFAILUREPERCENTAGE.fields_by_name['host_success_rate']._options = None
  _OUTLIEREJECTFAILUREPERCENTAGE.fields_by_name['host_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTFAILUREPERCENTAGE._options = None
  _OUTLIEREJECTFAILUREPERCENTAGE._serialized_options = b'\232\305\210\036:\n8envoy.data.cluster.v2alpha.OutlierEjectFailurePercentage'
  _globals['_OUTLIEREJECTIONTYPE']._serialized_start=1381
  _globals['_OUTLIEREJECTIONTYPE']._serialized_end=1604
  _globals['_ACTION']._serialized_start=1606
  _globals['_ACTION']._serialized_end=1638
  _globals['_OUTLIERDETECTIONEVENT']._serialized_start=235
  _globals['_OUTLIERDETECTIONEVENT']._serialized_end=929
  _globals['_OUTLIEREJECTSUCCESSRATE']._serialized_start=932
  _globals['_OUTLIEREJECTSUCCESSRATE']._serialized_end=1157
  _globals['_OUTLIEREJECTCONSECUTIVE']._serialized_start=1159
  _globals['_OUTLIEREJECTCONSECUTIVE']._serialized_end=1243
  _globals['_OUTLIEREJECTFAILUREPERCENTAGE']._serialized_start=1246
  _globals['_OUTLIEREJECTFAILUREPERCENTAGE']._serialized_end=1378
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/http_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import http_uri_pb2 as envoy_dot_config_dot_core_dot_v3_dot_http__uri__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'envoy/config/core/v3/http_service.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a#envoy/config/core/v3/http_uri.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x92\x01\n\x0bHttpService\x12/\n\x08http_uri\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.HttpUri\x12R\n\x16request_headers_to_add\x18\x02 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x42\x84\x01\n\"io.envoyproxy.envoy.config.core.v3B\x10HttpServiceProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.http_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\020HttpServiceProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _HTTPSERVICE.fields_by_name['request_headers_to_add']._options = None
  _HTTPSERVICE.fields_by_name['request_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _globals['_HTTPSERVICE']._serialized_start=192
  _globals['_HTTPSERVICE']._serialized_end=338
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/header_to_metadata/v2/header_to_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/config/filter/http/header_to_metadata/v2/header_to_metadata.proto\x12.envoy.config.filter.http.header_to_metadata.v2\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xfd\x05\n\x06\x43onfig\x12R\n\rrequest_rules\x18\x01 \x03(\x0b\x32;.envoy.config.filter.http.header_to_metadata.v2.Config.Rule\x12S\n\x0eresponse_rules\x18\x02 \x03(\x0b\x32;.envoy.config.filter.http.header_to_metadata.v2.Config.Rule\x1a\xf3\x01\n\x0cKeyValuePair\x12\x1a\n\x12metadata_namespace\x18\x01 \x01(\t\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\r\n\x05value\x18\x03 \x01(\t\x12N\n\x04type\x18\x04 \x01(\x0e\x32@.envoy.config.filter.http.header_to_metadata.v2.Config.ValueType\x12R\n\x06\x65ncode\x18\x05 \x01(\x0e\x32\x42.envoy.config.filter.http.header_to_metadata.v2.Config.ValueEncode\x1a\xf5\x01\n\x04Rule\x12\x1d\n\x06header\x18\x01 \x01(\tB\r\xfa\x42\nr\x08 \x01\xc0\x01\x01\xc8\x01\x00\x12^\n\x11on_header_present\x18\x02 \x01(\x0b\x32\x43.envoy.config.filter.http.header_to_metadata.v2.Config.KeyValuePair\x12^\n\x11on_header_missing\x18\x03 \x01(\x0b\x32\x43.envoy.config.filter.http.header_to_metadata.v2.Config.KeyValuePair\x12\x0e\n\x06remove\x18\x04 \x01(\x08\"7\n\tValueType\x12\n\n\x06STRING\x10\x00\x12\n\n\x06NUMBER\x10\x01\x12\x12\n\x0ePROTOBUF_VALUE\x10\x02\"#\n\x0bValueEncode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x42\x41SE64\x10\x01\x42\x86\x02\n<io.envoyproxy.envoy.config.filter.http.header_to_metadata.v2B\x15HeaderToMetadataProtoP\x01Zjgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/header_to_metadata/v2;header_to_metadatav2\xf2\x98\xfe\x8f\x05\x35\x12\x33\x65nvoy.extensions.filters.http.header_to_metadata.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.header_to_metadata.v2.header_to_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n<io.envoyproxy.envoy.config.filter.http.header_to_metadata.v2B\025HeaderToMetadataProtoP\001Zjgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/header_to_metadata/v2;header_to_metadatav2\362\230\376\217\0055\0223envoy.extensions.filters.http.header_to_metadata.v3\272\200\310\321\006\002\020\001'
  _CONFIG_KEYVALUEPAIR.fields_by_name['key']._options = None
  _CONFIG_KEYVALUEPAIR.fields_by_name['key']._serialized_options = b'\372B\004r\002 \001'
  _CONFIG_RULE.fields_by_name['header']._options = None
  _CONFIG_RULE.fields_by_name['header']._serialized_options = b'\372B\nr\010 \001\300\001\001\310\001\000'
  _globals['_CONFIG']._serialized_start=212
  _globals['_CONFIG']._serialized_end=977
  _globals['_CONFIG_KEYVALUEPAIR']._serialized_start=392
  _globals['_CONFIG_KEYVALUEPAIR']._serialized_end=635
  _globals['_CONFIG_RULE']._serialized_start=638
  _globals['_CONFIG_RULE']._serialized_end=883
  _globals['_CONFIG_VALUETYPE']._serialized_start=885
  _globals['_CONFIG_VALUETYPE']._serialized_end=940
  _globals['_CONFIG_VALUEENCODE']._serialized_start=942
  _globals['_CONFIG_VALUEENCODE']._serialized_end=977
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/ext_proc/v3/external_processor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.extensions.filters.http.ext_proc.v3 import processing_mode_pb2 as envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3_dot_processing__mode__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/service/ext_proc/v3/external_processor.proto\x12\x19\x65nvoy.service.ext_proc.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a?envoy/extensions/filters/http/ext_proc/v3/processing_mode.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fxds/annotations/v3/status.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xb6\x05\n\x11ProcessingRequest\x12\x41\n\x0frequest_headers\x18\x02 \x01(\x0b\x32&.envoy.service.ext_proc.v3.HttpHeadersH\x00\x12\x42\n\x10response_headers\x18\x03 \x01(\x0b\x32&.envoy.service.ext_proc.v3.HttpHeadersH\x00\x12;\n\x0crequest_body\x18\x04 \x01(\x0b\x32#.envoy.service.ext_proc.v3.HttpBodyH\x00\x12<\n\rresponse_body\x18\x05 \x01(\x0b\x32#.envoy.service.ext_proc.v3.HttpBodyH\x00\x12\x43\n\x10request_trailers\x18\x06 \x01(\x0b\x32\'.envoy.service.ext_proc.v3.HttpTrailersH\x00\x12\x44\n\x11response_trailers\x18\x07 \x01(\x0b\x32\'.envoy.service.ext_proc.v3.HttpTrailersH\x00\x12\x38\n\x10metadata_context\x18\x08 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata\x12P\n\nattributes\x18\t \x03(\x0b\x32<.envoy.service.ext_proc.v3.ProcessingRequest.AttributesEntry\x12\x1a\n\x12observability_mode\x18\n \x01(\x08\x1aJ\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\x42\x0e\n\x07request\x12\x03\xf8\x42\x01J\x04\x08\x01\x10\x02R\nasync_mode\"\xd8\x05\n\x12ProcessingResponse\x12\x45\n\x0frequest_headers\x18\x01 \x01(\x0b\x32*.envoy.service.ext_proc.v3.HeadersResponseH\x00\x12\x46\n\x10response_headers\x18\x02 \x01(\x0b\x32*.envoy.service.ext_proc.v3.HeadersResponseH\x00\x12?\n\x0crequest_body\x18\x03 \x01(\x0b\x32\'.envoy.service.ext_proc.v3.BodyResponseH\x00\x12@\n\rresponse_body\x18\x04 \x01(\x0b\x32\'.envoy.service.ext_proc.v3.BodyResponseH\x00\x12G\n\x10request_trailers\x18\x05 \x01(\x0b\x32+.envoy.service.ext_proc.v3.TrailersResponseH\x00\x12H\n\x11response_trailers\x18\x06 \x01(\x0b\x32+.envoy.service.ext_proc.v3.TrailersResponseH\x00\x12J\n\x12immediate_response\x18\x07 \x01(\x0b\x32,.envoy.service.ext_proc.v3.ImmediateResponseH\x00\x12\x31\n\x10\x64ynamic_metadata\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12P\n\rmode_override\x18\t \x01(\x0b\x32\x39.envoy.extensions.filters.http.ext_proc.v3.ProcessingMode\x12;\n\x18override_message_timeout\x18\n \x01(\x0b\x32\x19.google.protobuf.DurationB\x0f\n\x08response\x12\x03\xf8\x42\x01\"\xfb\x01\n\x0bHttpHeaders\x12\x30\n\x07headers\x18\x01 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMap\x12W\n\nattributes\x18\x02 \x03(\x0b\x32\x36.envoy.service.ext_proc.v3.HttpHeaders.AttributesEntryB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x15\n\rend_of_stream\x18\x03 \x01(\x08\x1aJ\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\"/\n\x08HttpBody\x12\x0c\n\x04\x62ody\x18\x01 \x01(\x0c\x12\x15\n\rend_of_stream\x18\x02 \x01(\x08\"A\n\x0cHttpTrailers\x12\x31\n\x08trailers\x18\x01 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMap\"N\n\x0fHeadersResponse\x12;\n\x08response\x18\x01 \x01(\x0b\x32).envoy.service.ext_proc.v3.CommonResponse\"K\n\x0c\x42odyResponse\x12;\n\x08response\x18\x01 \x01(\x0b\x32).envoy.service.ext_proc.v3.CommonResponse\"V\n\x10TrailersResponse\x12\x42\n\x0fheader_mutation\x18\x01 \x01(\x0b\x32).envoy.service.ext_proc.v3.HeaderMutation\"\xf0\x02\n\x0e\x43ommonResponse\x12R\n\x06status\x18\x01 \x01(\x0e\x32\x38.envoy.service.ext_proc.v3.CommonResponse.ResponseStatusB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x42\n\x0fheader_mutation\x18\x02 \x01(\x0b\x32).envoy.service.ext_proc.v3.HeaderMutation\x12>\n\rbody_mutation\x18\x03 \x01(\x0b\x32\'.envoy.service.ext_proc.v3.BodyMutation\x12\x31\n\x08trailers\x18\x04 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMap\x12\x19\n\x11\x63lear_route_cache\x18\x05 \x01(\x08\"8\n\x0eResponseStatus\x12\x0c\n\x08\x43ONTINUE\x10\x00\x12\x18\n\x14\x43ONTINUE_AND_REPLACE\x10\x01\"\xdf\x01\n\x11ImmediateResponse\x12\x33\n\x06status\x18\x01 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatusB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12:\n\x07headers\x18\x02 \x01(\x0b\x32).envoy.service.ext_proc.v3.HeaderMutation\x12\x0c\n\x04\x62ody\x18\x03 \x01(\x0c\x12:\n\x0bgrpc_status\x18\x04 \x01(\x0b\x32%.envoy.service.ext_proc.v3.GrpcStatus\x12\x0f\n\x07\x64\x65tails\x18\x05 \x01(\t\"\x1c\n\nGrpcStatus\x12\x0e\n\x06status\x18\x01 \x01(\r\"f\n\x0eHeaderMutation\x12<\n\x0bset_headers\x18\x01 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOption\x12\x16\n\x0eremove_headers\x18\x02 \x03(\t\";\n\x14StreamedBodyResponse\x12\x0c\n\x04\x62ody\x18\x01 \x01(\x0c\x12\x15\n\rend_of_stream\x18\x02 \x01(\x08\"\x98\x01\n\x0c\x42odyMutation\x12\x0e\n\x04\x62ody\x18\x01 \x01(\x0cH\x00\x12\x14\n\nclear_body\x18\x02 \x01(\x08H\x00\x12V\n\x11streamed_response\x18\x03 \x01(\x0b\x32/.envoy.service.ext_proc.v3.StreamedBodyResponseB\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01H\x00\x42\n\n\x08mutation2\x81\x01\n\x11\x45xternalProcessor\x12l\n\x07Process\x12,.envoy.service.ext_proc.v3.ProcessingRequest\x1a-.envoy.service.ext_proc.v3.ProcessingResponse\"\x00(\x01\x30\x01\x42\x98\x01\n\'io.envoyproxy.envoy.service.ext_proc.v3B\x16\x45xternalProcessorProtoP\x01ZKgithub.com/envoyproxy/go-control-plane/envoy/service/ext_proc/v3;ext_procv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.ext_proc.v3.external_processor_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'io.envoyproxy.envoy.service.ext_proc.v3B\026ExternalProcessorProtoP\001ZKgithub.com/envoyproxy/go-control-plane/envoy/service/ext_proc/v3;ext_procv3\272\200\310\321\006\002\020\002'
  _PROCESSINGREQUEST_ATTRIBUTESENTRY._options = None
  _PROCESSINGREQUEST_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _PROCESSINGREQUEST.oneofs_by_name['request']._options = None
  _PROCESSINGREQUEST.oneofs_by_name['request']._serialized_options = b'\370B\001'
  _PROCESSINGRESPONSE.oneofs_by_name['response']._options = None
  _PROCESSINGRESPONSE.oneofs_by_name['response']._serialized_options = b'\370B\001'
  _HTTPHEADERS_ATTRIBUTESENTRY._options = None
  _HTTPHEADERS_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _HTTPHEADERS.fields_by_name['attributes']._options = None
  _HTTPHEADERS.fields_by_name['attributes']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _COMMONRESPONSE.fields_by_name['status']._options = None
  _COMMONRESPONSE.fields_by_name['status']._serialized_options = b'\372B\005\202\001\002\020\001'
  _IMMEDIATERESPONSE.fields_by_name['status']._options = None
  _IMMEDIATERESPONSE.fields_by_name['status']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BODYMUTATION.fields_by_name['streamed_response']._options = None
  _BODYMUTATION.fields_by_name['streamed_response']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_PROCESSINGREQUEST']._serialized_start=401
  _globals['_PROCESSINGREQUEST']._serialized_end=1095
  _globals['_PROCESSINGREQUEST_ATTRIBUTESENTRY']._serialized_start=987
  _globals['_PROCESSINGREQUEST_ATTRIBUTESENTRY']._serialized_end=1061
  _globals['_PROCESSINGRESPONSE']._serialized_start=1098
  _globals['_PROCESSINGRESPONSE']._serialized_end=1826
  _globals['_HTTPHEADERS']._serialized_start=1829
  _globals['_HTTPHEADERS']._serialized_end=2080
  _globals['_HTTPHEADERS_ATTRIBUTESENTRY']._serialized_start=987
  _globals['_HTTPHEADERS_ATTRIBUTESENTRY']._serialized_end=1061
  _globals['_HTTPBODY']._serialized_start=2082
  _globals['_HTTPBODY']._serialized_end=2129
  _globals['_HTTPTRAILERS']._serialized_start=2131
  _globals['_HTTPTRAILERS']._serialized_end=2196
  _globals['_HEADERSRESPONSE']._serialized_start=2198
  _globals['_HEADERSRESPONSE']._serialized_end=2276
  _globals['_BODYRESPONSE']._serialized_start=2278
  _globals['_BODYRESPONSE']._serialized_end=2353
  _globals['_TRAILERSRESPONSE']._serialized_start=2355
  _globals['_TRAILERSRESPONSE']._serialized_end=2441
  _globals['_COMMONRESPONSE']._serialized_start=2444
  _globals['_COMMONRESPONSE']._serialized_end=2812
  _globals['_COMMONRESPONSE_RESPONSESTATUS']._serialized_start=2756
  _globals['_COMMONRESPONSE_RESPONSESTATUS']._serialized_end=2812
  _globals['_IMMEDIATERESPONSE']._serialized_start=2815
  _globals['_IMMEDIATERESPONSE']._serialized_end=3038
  _globals['_GRPCSTATUS']._serialized_start=3040
  _globals['_GRPCSTATUS']._serialized_end=3068
  _globals['_HEADERMUTATION']._serialized_start=3070
  _globals['_HEADERMUTATION']._serialized_end=3172
  _globals['_STREAMEDBODYRESPONSE']._serialized_start=3174
  _globals['_STREAMEDBODYRESPONSE']._serialized_end=3233
  _globals['_BODYMUTATION']._serialized_start=3236
  _globals['_BODYMUTATION']._serialized_end=3388
  _globals['_EXTERNALPROCESSOR']._serialized_start=3391
  _globals['_EXTERNALPROCESSOR']._serialized_end=3520
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/upstreams/tcp/v3/tcp_protocol_options.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/extensions/upstreams/tcp/v3/tcp_protocol_options.proto\x12!envoy.extensions.upstreams.tcp.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\"E\n\x12TcpProtocolOptions\x12/\n\x0cidle_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\xa4\x01\n/io.envoyproxy.envoy.extensions.upstreams.tcp.v3B\x17TcpProtocolOptionsProtoP\x01ZNgithub.com/envoyproxy/go-control-plane/envoy/extensions/upstreams/tcp/v3;tcpv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.upstreams.tcp.v3.tcp_protocol_options_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n/io.envoyproxy.envoy.extensions.upstreams.tcp.v3B\027TcpProtocolOptionsProtoP\001ZNgithub.com/envoyproxy/go-control-plane/envoy/extensions/upstreams/tcp/v3;tcpv3\272\200\310\321\006\002\020\002'
  _globals['_TCPPROTOCOLOPTIONS']._serialized_start=162
  _globals['_TCPPROTOCOLOPTIONS']._serialized_end=231
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/csrf/v3/csrf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0envoy/extensions/filters/http/csrf/v3/csrf.proto\x12%envoy.extensions.filters.http.csrf.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9c\x02\n\nCsrfPolicy\x12P\n\x0e\x66ilter_enabled\x18\x01 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercentB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x46\n\x0eshadow_enabled\x18\x02 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12@\n\x12\x61\x64\x64itional_origins\x18\x03 \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcher:2\x9a\xc5\x88\x1e-\n+envoy.config.filter.http.csrf.v2.CsrfPolicyB\x9f\x01\n3io.envoyproxy.envoy.extensions.filters.http.csrf.v3B\tCsrfProtoP\x01ZSgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/csrf/v3;csrfv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.csrf.v3.csrf_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n3io.envoyproxy.envoy.extensions.filters.http.csrf.v3B\tCsrfProtoP\001ZSgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/csrf/v3;csrfv3\272\200\310\321\006\002\020\002'
  _CSRFPOLICY.fields_by_name['filter_enabled']._options = None
  _CSRFPOLICY.fields_by_name['filter_enabled']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CSRFPOLICY._options = None
  _CSRFPOLICY._serialized_options = b'\232\305\210\036-\n+envoy.config.filter.http.csrf.v2.CsrfPolicy'
  _globals['_CSRFPOLICY']._serialized_start=252
  _globals['_CSRFPOLICY']._serialized_end=536
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/service/orca/v3/orca.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.data.orca.v3 import orca_load_report_pb2 as xds_dot_data_dot_orca_dot_v3_dot_orca__load__report__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1exds/service/orca/v3/orca.proto\x12\x13xds.service.orca.v3\x1a\'xds/data/orca/v3/orca_load_report.proto\x1a\x1egoogle/protobuf/duration.proto\"g\n\x15OrcaLoadReportRequest\x12\x32\n\x0freport_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1a\n\x12request_cost_names\x18\x02 \x03(\t2u\n\x0eOpenRcaService\x12\x63\n\x11StreamCoreMetrics\x12*.xds.service.orca.v3.OrcaLoadReportRequest\x1a .xds.data.orca.v3.OrcaLoadReport0\x01\x42Y\n\x1e\x63om.github.xds.service.orca.v3B\tOrcaProtoP\x01Z*github.com/cncf/xds/go/xds/service/orca/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.service.orca.v3.orca_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.github.xds.service.orca.v3B\tOrcaProtoP\001Z*github.com/cncf/xds/go/xds/service/orca/v3'
  _globals['_ORCALOADREPORTREQUEST']._serialized_start=128
  _globals['_ORCALOADREPORTREQUEST']._serialized_end=231
  _globals['_OPENRCASERVICE']._serialized_start=233
  _globals['_OPENRCASERVICE']._serialized_end=350
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v3/value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import number_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_number__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/type/matcher/v3/value.proto\x12\x15\x65nvoy.type.matcher.v3\x1a\"envoy/type/matcher/v3/number.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xeb\x03\n\x0cValueMatcher\x12\x43\n\nnull_match\x18\x01 \x01(\x0b\x32-.envoy.type.matcher.v3.ValueMatcher.NullMatchH\x00\x12<\n\x0c\x64ouble_match\x18\x02 \x01(\x0b\x32$.envoy.type.matcher.v3.DoubleMatcherH\x00\x12<\n\x0cstring_match\x18\x03 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcherH\x00\x12\x14\n\nbool_match\x18\x04 \x01(\x08H\x00\x12\x17\n\rpresent_match\x18\x05 \x01(\x08H\x00\x12\x38\n\nlist_match\x18\x06 \x01(\x0b\x32\".envoy.type.matcher.v3.ListMatcherH\x00\x12\x34\n\x08or_match\x18\x07 \x01(\x0b\x32 .envoy.type.matcher.v3.OrMatcherH\x00\x1a=\n\tNullMatch:0\x9a\xc5\x88\x1e+\n)envoy.type.matcher.ValueMatcher.NullMatch:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.type.matcher.ValueMatcherB\x14\n\rmatch_pattern\x12\x03\xf8\x42\x01\"\x81\x01\n\x0bListMatcher\x12\x35\n\x06one_of\x18\x01 \x01(\x0b\x32#.envoy.type.matcher.v3.ValueMatcherH\x00:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.type.matcher.ListMatcherB\x14\n\rmatch_pattern\x12\x03\xf8\x42\x01\"R\n\tOrMatcher\x12\x45\n\x0evalue_matchers\x18\x01 \x03(\x0b\x32#.envoy.type.matcher.v3.ValueMatcherB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x42\x83\x01\n#io.envoyproxy.envoy.type.matcher.v3B\nValueProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.v3.value_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.type.matcher.v3B\nValueProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\272\200\310\321\006\002\020\002'
  _VALUEMATCHER_NULLMATCH._options = None
  _VALUEMATCHER_NULLMATCH._serialized_options = b'\232\305\210\036+\n)envoy.type.matcher.ValueMatcher.NullMatch'
  _VALUEMATCHER.oneofs_by_name['match_pattern']._options = None
  _VALUEMATCHER.oneofs_by_name['match_pattern']._serialized_options = b'\370B\001'
  _VALUEMATCHER._options = None
  _VALUEMATCHER._serialized_options = b'\232\305\210\036!\n\037envoy.type.matcher.ValueMatcher'
  _LISTMATCHER.oneofs_by_name['match_pattern']._options = None
  _LISTMATCHER.oneofs_by_name['match_pattern']._serialized_options = b'\370B\001'
  _LISTMATCHER._options = None
  _LISTMATCHER._serialized_options = b'\232\305\210\036 \n\036envoy.type.matcher.ListMatcher'
  _ORMATCHER.fields_by_name['value_matchers']._options = None
  _ORMATCHER.fields_by_name['value_matchers']._serialized_options = b'\372B\005\222\001\002\010\002'
  _globals['_VALUEMATCHER']._serialized_start=224
  _globals['_VALUEMATCHER']._serialized_end=715
  _globals['_VALUEMATCHER_NULLMATCH']._serialized_start=592
  _globals['_VALUEMATCHER_NULLMATCH']._serialized_end=653
  _globals['_LISTMATCHER']._serialized_start=718
  _globals['_LISTMATCHER']._serialized_end=847
  _globals['_ORMATCHER']._serialized_start=849
  _globals['_ORMATCHER']._serialized_end=931
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from envoy.service.rate_limit_quota.v3 import rlqs_pb2 as envoy_dot_service_dot_rate__limit__quota_dot_v3_dot_rlqs__pb2


class RateLimitQuotaServiceStub(object):
    """[#protodoc-title: Rate Limit Quota Service (RLQS)]

    The Rate Limit Quota Service (RLQS) is a Envoy global rate limiting service that allows to
    delegate rate limit decisions to a remote service. The service will aggregate the usage reports
    from multiple data plane instances, and distribute Rate Limit Assignments to each instance
    based on its business logic. The logic is outside of the scope of the protocol API.

    The protocol is designed as a streaming-first API. It utilizes watch-like subscription model.
    The data plane groups requests into Quota Buckets as directed by the filter config,
    and periodically reports them to the RLQS server along with the Bucket identifier, :ref:`BucketId
    <envoy_v3_api_msg_service.rate_limit_quota.v3.BucketId>`. Once RLQS server has collected enough
    reports to make a decision, it'll send back the assignment with the rate limiting instructions.

    The first report sent by the data plane is interpreted by the RLQS server as a "watch" request,
    indicating that the data plane instance is interested in receiving further updates for the
    ``BucketId``. From then on, RLQS server may push assignments to this instance at will, even if
    the instance is not sending usage reports. It's the responsibility of the RLQS server
    to determine when the data plane instance didn't send ``BucketId`` reports for too long,
    and to respond with the :ref:`AbandonAction
    <envoy_v3_api_msg_service.rate_limit_quota.v3.RateLimitQuotaResponse.BucketAction.AbandonAction>`,
    indicating that the server has now stopped sending quota assignments for the ``BucketId`` bucket,
    and the data plane instance should :ref:`abandon
    <envoy_v3_api_field_service.rate_limit_quota.v3.RateLimitQuotaResponse.BucketAction.abandon_action>`
    it.

    If for any reason the RLQS client doesn't receive the initial assignment for the reported bucket,
    in order to prevent memory exhaustion, the data plane will limit the time such bucket
    is retained. The exact time to wait for the initial assignment is chosen by the filter,
    and may vary based on the implementation.
    Once the duration ends, the data plane will stop reporting bucket usage, reject any enqueued
    requests, and purge the bucket from the memory. Subsequent requests matched into the bucket
    will re-initialize the bucket in the "no assignment" state, restarting the reports.

    Refer to Rate Limit Quota :ref:`configuration overview <config_http_filters_rate_limit_quota>`
    for further details.

    Defines the Rate Limit Quota Service (RLQS).
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamRateLimitQuotas = channel.stream_stream(
                '/envoy.service.rate_limit_quota.v3.RateLimitQuotaService/StreamRateLimitQuotas',
                request_serializer=envoy_dot_service_dot_rate__limit__quota_dot_v3_dot_rlqs__pb2.RateLimitQuotaUsageReports.SerializeToString,
                response_deserializer=envoy_dot_service_dot_rate__limit__quota_dot_v3_dot_rlqs__pb2.RateLimitQuotaResponse.FromString,
                )


class RateLimitQuotaServiceServicer(object):
    """[#protodoc-title: Rate Limit Quota Service (RLQS)]

    The Rate Limit Quota Service (RLQS) is a Envoy global rate limiting service that allows to
    delegate rate limit decisions to a remote service. The service will aggregate the usage reports
    from multiple data plane instances, and distribute Rate Limit Assignments to each instance
    based on its business logic. The logic is outside of the scope of the protocol API.

    The protocol is designed as a streaming-first API. It utilizes watch-like subscription model.
    The data plane groups requests into Quota Buckets as directed by the filter config,
    and periodically reports them to the RLQS server along with the Bucket identifier, :ref:`BucketId
    <envoy_v3_api_msg_service.rate_limit_quota.v3.BucketId>`. Once RLQS server has collected enough
    reports to make a decision, it'll send back the assignment with the rate limiting instructions.

    The first report sent by the data plane is interpreted by the RLQS server as a "watch" request,
    indicating that the data plane instance is interested in receiving further updates for the
    ``BucketId``. From then on, RLQS server may push assignments to this instance at will, even if
    the instance is not sending usage reports. It's the responsibility of the RLQS server
    to determine when the data plane instance didn't send ``BucketId`` reports for too long,
    and to respond with the :ref:`AbandonAction
    <envoy_v3_api_msg_service.rate_limit_quota.v3.RateLimitQuotaResponse.BucketAction.AbandonAction>`,
    indicating that the server has now stopped sending quota assignments for the ``BucketId`` bucket,
    and the data plane instance should :ref:`abandon
    <envoy_v3_api_field_service.rate_limit_quota.v3.RateLimitQuotaResponse.BucketAction.abandon_action>`
    it.

    If for any reason the RLQS client doesn't receive the initial assignment for the reported bucket,
    in order to prevent memory exhaustion, the data plane will limit the time such bucket
    is retained. The exact time to wait for the initial assignment is chosen by the filter,
    and may vary based on the implementation.
    Once the duration ends, the data plane will stop reporting bucket usage, reject any enqueued
    requests, and purge the bucket from the memory. Subsequent requests matched into the bucket
    will re-initialize the bucket in the "no assignment" state, restarting the reports.

    Refer to Rate Limit Quota :ref:`configuration overview <config_http_filters_rate_limit_quota>`
    for further details.

    Defines the Rate Limit Quota Service (RLQS).
    """

    def StreamRateLimitQuotas(self, request_iterator, context):
        """Main communication channel: the data plane sends usage reports to the RLQS server,
        and the server asynchronously responding with the assignments.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RateLimitQuotaServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamRateLimitQuotas': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamRateLimitQuotas,
                    request_deserializer=envoy_dot_service_dot_rate__limit__quota_dot_v3_dot_rlqs__pb2.RateLimitQuotaUsageReports.FromString,
                    response_serializer=envoy_dot_service_dot_rate__limit__quota_dot_v3_dot_rlqs__pb2.RateLimitQuotaResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.rate_limit_quota.v3.RateLimitQuotaService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RateLimitQuotaService(object):
    """[#protodoc-title: Rate Limit Quota Service (RLQS)]

    The Rate Limit Quota Service (RLQS) is a Envoy global rate limiting service that allows to
    delegate rate limit decisions to a remote service. The service will aggregate the usage reports
    from multiple data plane instances, and distribute Rate Limit Assignments to each instance
    based on its business logic. The logic is outside of the scope of the protocol API.

    The protocol is designed as a streaming-first API. It utilizes watch-like subscription model.
    The data plane groups requests into Quota Buckets as directed by the filter config,
    and periodically reports them to the RLQS server along with the Bucket identifier, :ref:`BucketId
    <envoy_v3_api_msg_service.rate_limit_quota.v3.BucketId>`. Once RLQS server has collected enough
    reports to make a decision, it'll send back the assignment with the rate limiting instructions.

    The first report sent by the data plane is interpreted by the RLQS server as a "watch" request,
    indicating that the data plane instance is interested in receiving further updates for the
    ``BucketId``. From then on, RLQS server may push assignments to this instance at will, even if
    the instance is not sending usage reports. It's the responsibility of the RLQS server
    to determine when the data plane instance didn't send ``BucketId`` reports for too long,
    and to respond with the :ref:`AbandonAction
    <envoy_v3_api_msg_service.rate_limit_quota.v3.RateLimitQuotaResponse.BucketAction.AbandonAction>`,
    indicating that the server has now stopped sending quota assignments for the ``BucketId`` bucket,
    and the data plane instance should :ref:`abandon
    <envoy_v3_api_field_service.rate_limit_quota.v3.RateLimitQuotaResponse.BucketAction.abandon_action>`
    it.

    If for any reason the RLQS client doesn't receive the initial assignment for the reported bucket,
    in order to prevent memory exhaustion, the data plane will limit the time such bucket
    is retained. The exact time to wait for the initial assignment is chosen by the filter,
    and may vary based on the implementation.
    Once the duration ends, the data plane will stop reporting bucket usage, reject any enqueued
    requests, and purge the bucket from the memory. Subsequent requests matched into the bucket
    will re-initialize the bucket in the "no assignment" state, restarting the reports.

    Refer to Rate Limit Quota :ref:`configuration overview <config_http_filters_rate_limit_quota>`
    for further details.

    Defines the Rate Limit Quota Service (RLQS).
    """

    @staticmethod
    def StreamRateLimitQuotas(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/envoy.service.rate_limit_quota.v3.RateLimitQuotaService/StreamRateLimitQuotas',
            envoy_dot_service_dot_rate__limit__quota_dot_v3_dot_rlqs__pb2.RateLimitQuotaUsageReports.SerializeToString,
            envoy_dot_service_dot_rate__limit__quota_dot_v3_dot_rlqs__pb2.RateLimitQuotaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicecontrol/v1/quota_controller.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api.servicecontrol.v1 import metric_value_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_metric__value__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3google/api/servicecontrol/v1/quota_controller.proto\x12\x1cgoogle.api.servicecontrol.v1\x1a\x1cgoogle/api/annotations.proto\x1a/google/api/servicecontrol/v1/metric_value.proto\x1a\x17google/rpc/status.proto\x1a\x17google/api/client.proto\"\x91\x01\n\x14\x41llocateQuotaRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12H\n\x12\x61llocate_operation\x18\x02 \x01(\x0b\x32,.google.api.servicecontrol.v1.QuotaOperation\x12\x19\n\x11service_config_id\x18\x04 \x01(\t\"\xc6\x03\n\x0eQuotaOperation\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\x13\n\x0bmethod_name\x18\x02 \x01(\t\x12\x13\n\x0b\x63onsumer_id\x18\x03 \x01(\t\x12H\n\x06labels\x18\x04 \x03(\x0b\x32\x38.google.api.servicecontrol.v1.QuotaOperation.LabelsEntry\x12\x43\n\rquota_metrics\x18\x05 \x03(\x0b\x32,.google.api.servicecontrol.v1.MetricValueSet\x12J\n\nquota_mode\x18\x06 \x01(\x0e\x32\x36.google.api.servicecontrol.v1.QuotaOperation.QuotaMode\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n\tQuotaMode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\x0f\n\x0b\x42\x45ST_EFFORT\x10\x02\x12\x0e\n\nCHECK_ONLY\x10\x03\x12\x0e\n\nQUERY_ONLY\x10\x04\x12\x0f\n\x0b\x41\x44JUST_ONLY\x10\x05\"\xd0\x01\n\x15\x41llocateQuotaResponse\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\x41\n\x0f\x61llocate_errors\x18\x02 \x03(\x0b\x32(.google.api.servicecontrol.v1.QuotaError\x12\x43\n\rquota_metrics\x18\x03 \x03(\x0b\x32,.google.api.servicecontrol.v1.MetricValueSet\x12\x19\n\x11service_config_id\x18\x04 \x01(\t\"\x9c\x02\n\nQuotaError\x12;\n\x04\x63ode\x18\x01 \x01(\x0e\x32-.google.api.servicecontrol.v1.QuotaError.Code\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\"\n\x06status\x18\x04 \x01(\x0b\x32\x12.google.rpc.Status\"\x86\x01\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x16\n\x12\x42ILLING_NOT_ACTIVE\x10k\x12\x13\n\x0fPROJECT_DELETED\x10l\x12\x13\n\x0f\x41PI_KEY_INVALID\x10i\x12\x13\n\x0f\x41PI_KEY_EXPIRED\x10p2\xc5\x02\n\x0fQuotaController\x12\xae\x01\n\rAllocateQuota\x12\x32.google.api.servicecontrol.v1.AllocateQuotaRequest\x1a\x33.google.api.servicecontrol.v1.AllocateQuotaResponse\"4\x82\xd3\xe4\x93\x02.\")/v1/services/{service_name}:allocateQuota:\x01*\x1a\x80\x01\xca\x41\x1dservicecontrol.googleapis.com\xd2\x41]https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/servicecontrolB\xef\x01\n com.google.api.servicecontrol.v1B\x14QuotaControllerProtoP\x01ZJcloud.google.com/go/servicecontrol/apiv1/servicecontrolpb;servicecontrolpb\xf8\x01\x01\xaa\x02\x1eGoogle.Cloud.ServiceControl.V1\xca\x02\x1eGoogle\\Cloud\\ServiceControl\\V1\xea\x02!Google::Cloud::ServiceControl::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.servicecontrol.v1.quota_controller_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.google.api.servicecontrol.v1B\024QuotaControllerProtoP\001ZJcloud.google.com/go/servicecontrol/apiv1/servicecontrolpb;servicecontrolpb\370\001\001\252\002\036Google.Cloud.ServiceControl.V1\312\002\036Google\\Cloud\\ServiceControl\\V1\352\002!Google::Cloud::ServiceControl::V1'
  _QUOTAOPERATION_LABELSENTRY._options = None
  _QUOTAOPERATION_LABELSENTRY._serialized_options = b'8\001'
  _QUOTACONTROLLER._options = None
  _QUOTACONTROLLER._serialized_options = b'\312A\035servicecontrol.googleapis.com\322A]https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/servicecontrol'
  _QUOTACONTROLLER.methods_by_name['AllocateQuota']._options = None
  _QUOTACONTROLLER.methods_by_name['AllocateQuota']._serialized_options = b'\202\323\344\223\002.\")/v1/services/{service_name}:allocateQuota:\001*'
  _globals['_ALLOCATEQUOTAREQUEST']._serialized_start=215
  _globals['_ALLOCATEQUOTAREQUEST']._serialized_end=360
  _globals['_QUOTAOPERATION']._serialized_start=363
  _globals['_QUOTAOPERATION']._serialized_end=817
  _globals['_QUOTAOPERATION_LABELSENTRY']._serialized_start=664
  _globals['_QUOTAOPERATION_LABELSENTRY']._serialized_end=709
  _globals['_QUOTAOPERATION_QUOTAMODE']._serialized_start=711
  _globals['_QUOTAOPERATION_QUOTAMODE']._serialized_end=817
  _globals['_ALLOCATEQUOTARESPONSE']._serialized_start=820
  _globals['_ALLOCATEQUOTARESPONSE']._serialized_end=1028
  _globals['_QUOTAERROR']._serialized_start=1031
  _globals['_QUOTAERROR']._serialized_end=1315
  _globals['_QUOTAERROR_CODE']._serialized_start=1181
  _globals['_QUOTAERROR_CODE']._serialized_end=1315
  _globals['_QUOTACONTROLLER']._serialized_start=1318
  _globals['_QUOTACONTROLLER']._serialized_end=1643
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/http/custom_response/local_response_policy/v3/local_response_policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import substitution_format_string_pb2 as envoy_dot_config_dot_core_dot_v3_dot_substitution__format__string__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZenvoy/extensions/http/custom_response/local_response_policy/v3/local_response_policy.proto\x12>envoy.extensions.http.custom_response.local_response_policy.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x35\x65nvoy/config/core/v3/substitution_format_string.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9f\x02\n\x13LocalResponsePolicy\x12.\n\x04\x62ody\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12\x43\n\x0b\x62ody_format\x18\x02 \x01(\x0b\x32..envoy.config.core.v3.SubstitutionFormatString\x12>\n\x0bstatus_code\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0b\xfa\x42\x08*\x06\x10\xd8\x04(\xc8\x01\x12S\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x42\xf9\x01\nLio.envoyproxy.envoy.extensions.http.custom_response.local_response_policy.v3B\x18LocalResponsePolicyProtoP\x01Z}github.com/envoyproxy/go-control-plane/envoy/extensions/http/custom_response/local_response_policy/v3;local_response_policyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.http.custom_response.local_response_policy.v3.local_response_policy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nLio.envoyproxy.envoy.extensions.http.custom_response.local_response_policy.v3B\030LocalResponsePolicyProtoP\001Z}github.com/envoyproxy/go-control-plane/envoy/extensions/http/custom_response/local_response_policy/v3;local_response_policyv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _LOCALRESPONSEPOLICY.fields_by_name['status_code']._options = None
  _LOCALRESPONSEPOLICY.fields_by_name['status_code']._serialized_options = b'\372B\010*\006\020\330\004(\310\001'
  _LOCALRESPONSEPOLICY.fields_by_name['response_headers_to_add']._options = None
  _LOCALRESPONSEPOLICY.fields_by_name['response_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _globals['_LOCALRESPONSEPOLICY']._serialized_start=368
  _globals['_LOCALRESPONSEPOLICY']._serialized_end=655
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/event_reporting/v2alpha/event_reporting_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCenvoy/service/event_reporting/v2alpha/event_reporting_service.proto\x12%envoy.service.event_reporting.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdf\x01\n\x13StreamEventsRequest\x12Y\n\nidentifier\x18\x01 \x01(\x0b\x32\x45.envoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier\x12.\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a=\n\nIdentifier\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x16\n\x14StreamEventsResponse2\xa7\x01\n\x15\x45ventReportingService\x12\x8d\x01\n\x0cStreamEvents\x12:.envoy.service.event_reporting.v2alpha.StreamEventsRequest\x1a;.envoy.service.event_reporting.v2alpha.StreamEventsResponse\"\x00(\x01\x30\x01\x42\xd1\x01\n3io.envoyproxy.envoy.service.event_reporting.v2alphaB\x1a\x45ventReportingServiceProtoP\x01ZLgithub.com/envoyproxy/go-control-plane/envoy/service/event_reporting/v2alpha\xf2\x98\xfe\x8f\x05\"\x12 envoy.service.event_reporting.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.event_reporting.v2alpha.event_reporting_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n3io.envoyproxy.envoy.service.event_reporting.v2alphaB\032EventReportingServiceProtoP\001ZLgithub.com/envoyproxy/go-control-plane/envoy/service/event_reporting/v2alpha\362\230\376\217\005\"\022 envoy.service.event_reporting.v3\272\200\310\321\006\002\020\001'
  _STREAMEVENTSREQUEST_IDENTIFIER.fields_by_name['node']._options = None
  _STREAMEVENTSREQUEST_IDENTIFIER.fields_by_name['node']._serialized_options = b'\372B\005\212\001\002\020\001'
  _STREAMEVENTSREQUEST.fields_by_name['events']._options = None
  _STREAMEVENTSREQUEST.fields_by_name['events']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_STREAMEVENTSREQUEST']._serialized_start=256
  _globals['_STREAMEVENTSREQUEST']._serialized_end=479
  _globals['_STREAMEVENTSREQUEST_IDENTIFIER']._serialized_start=418
  _globals['_STREAMEVENTSREQUEST_IDENTIFIER']._serialized_end=479
  _globals['_STREAMEVENTSRESPONSE']._serialized_start=481
  _globals['_STREAMEVENTSRESPONSE']._serialized_end=503
  _globals['_EVENTREPORTINGSERVICE']._serialized_start=506
  _globals['_EVENTREPORTINGSERVICE']._serialized_end=673
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/error_reason.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgoogle/api/error_reason.proto\x12\ngoogle.api*\x8a\x07\n\x0b\x45rrorReason\x12\x1c\n\x18\x45RROR_REASON_UNSPECIFIED\x10\x00\x12\x14\n\x10SERVICE_DISABLED\x10\x01\x12\x14\n\x10\x42ILLING_DISABLED\x10\x02\x12\x13\n\x0f\x41PI_KEY_INVALID\x10\x03\x12\x1b\n\x17\x41PI_KEY_SERVICE_BLOCKED\x10\x04\x12!\n\x1d\x41PI_KEY_HTTP_REFERRER_BLOCKED\x10\x07\x12\x1e\n\x1a\x41PI_KEY_IP_ADDRESS_BLOCKED\x10\x08\x12\x1f\n\x1b\x41PI_KEY_ANDROID_APP_BLOCKED\x10\t\x12\x1b\n\x17\x41PI_KEY_IOS_APP_BLOCKED\x10\r\x12\x17\n\x13RATE_LIMIT_EXCEEDED\x10\x05\x12\x1b\n\x17RESOURCE_QUOTA_EXCEEDED\x10\x06\x12 \n\x1cLOCATION_TAX_POLICY_VIOLATED\x10\n\x12\x17\n\x13USER_PROJECT_DENIED\x10\x0b\x12\x16\n\x12\x43ONSUMER_SUSPENDED\x10\x0c\x12\x14\n\x10\x43ONSUMER_INVALID\x10\x0e\x12\x1c\n\x18SECURITY_POLICY_VIOLATED\x10\x0f\x12\x18\n\x14\x41\x43\x43\x45SS_TOKEN_EXPIRED\x10\x10\x12#\n\x1f\x41\x43\x43\x45SS_TOKEN_SCOPE_INSUFFICIENT\x10\x11\x12\x19\n\x15\x41\x43\x43OUNT_STATE_INVALID\x10\x12\x12!\n\x1d\x41\x43\x43\x45SS_TOKEN_TYPE_UNSUPPORTED\x10\x13\x12\x17\n\x13\x43REDENTIALS_MISSING\x10\x14\x12\x1c\n\x18RESOURCE_PROJECT_INVALID\x10\x15\x12\x1a\n\x16SESSION_COOKIE_INVALID\x10\x17\x12\x19\n\x15USER_BLOCKED_BY_ADMIN\x10\x18\x12\'\n#RESOURCE_USAGE_RESTRICTION_VIOLATED\x10\x19\x12 \n\x1cSYSTEM_PARAMETER_UNSUPPORTED\x10\x1a\x12\x1d\n\x19ORG_RESTRICTION_VIOLATION\x10\x1b\x12\"\n\x1eORG_RESTRICTION_HEADER_INVALID\x10\x1c\x12\x17\n\x13SERVICE_NOT_VISIBLE\x10\x1d\x12\x11\n\rGCP_SUSPENDED\x10\x1e\x12\x1c\n\x18LOCATION_POLICY_VIOLATED\x10\x1f\x42p\n\x0e\x63om.google.apiB\x10\x45rrorReasonProtoP\x01ZCgoogle.golang.org/genproto/googleapis/api/error_reason;error_reason\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.error_reason_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\020ErrorReasonProtoP\001ZCgoogle.golang.org/genproto/googleapis/api/error_reason;error_reason\242\002\004GAPI'
  _globals['_ERRORREASON']._serialized_start=46
  _globals['_ERRORREASON']._serialized_end=952
# @@protoc_insertion_point(module_scope)



#! /usr/bin/env python3
# Copyright 2021 The gRPC Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""A PyPI package for xDS protos generated Python code."""

import os

import setuptools

import grpc_version
import python_version

WORK_DIR = os.path.dirname(os.path.abspath(__file__))

# Ensure we're in the proper directory whether or not we're being used by pip.
os.chdir(WORK_DIR)

EXCLUDE_PYTHON_FILES = ["generated_file_import_test.py", "build.py"]

# Use setuptools to build Python package
with open(os.path.join(WORK_DIR, "README.rst"), "r") as f:
    LONG_DESCRIPTION = f.read()
PACKAGES = setuptools.find_packages(where=".", exclude=EXCLUDE_PYTHON_FILES)
CLASSIFIERS = [
    "Development Status :: 3 - Alpha",
    "Programming Language :: Python",
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: Apache Software License",
]
INSTALL_REQUIRES = [
    "grpcio>=1.49.0",
    "protobuf>=5.26.1,<6.0dev",
]

SETUP_REQUIRES = INSTALL_REQUIRES + ["grpcio-tools>=1.49.0"]


setuptools.setup(
    name="xds-protos",
    version=grpc_version.VERSION,
    packages=PACKAGES,
    description="Generated Python code from envoyproxy/data-plane-api",
    long_description_content_type="text/x-rst",
    long_description=LONG_DESCRIPTION,
    author="The gRPC Authors",
    author_email="grpc-io@googlegroups.com",
    url="https://grpc.io",
    license="Apache License 2.0",
    python_requires=f">={python_version.MIN_PYTHON_VERSION}",
    install_requires=INSTALL_REQUIRES,
    setup_requires=SETUP_REQUIRES,
    classifiers=CLASSIFIERS,
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/transport_socket/tap/v2alpha/tap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.config.common.tap.v2alpha import common_pb2 as envoy_dot_config_dot_common_dot_tap_dot_v2alpha_dot_common__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3envoy/config/transport_socket/tap/v2alpha/tap.proto\x12)envoy.config.transport_socket.tap.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a,envoy/config/common/tap/v2alpha/common.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa6\x01\n\x03Tap\x12W\n\rcommon_config\x18\x01 \x01(\x0b\x32\x36.envoy.config.common.tap.v2alpha.CommonExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x46\n\x10transport_socket\x18\x02 \x01(\x0b\x32\".envoy.api.v2.core.TransportSocketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\xd2\x01\n7io.envoyproxy.envoy.config.transport_socket.tap.v2alphaB\x08TapProtoP\x01ZPgithub.com/envoyproxy/go-control-plane/envoy/config/transport_socket/tap/v2alpha\xf2\x98\xfe\x8f\x05+\x12)envoy.extensions.transport_sockets.tap.v3\xba\x80\xc8\xd1\x06\x04\x08\x01\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.transport_socket.tap.v2alpha.tap_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7io.envoyproxy.envoy.config.transport_socket.tap.v2alphaB\010TapProtoP\001ZPgithub.com/envoyproxy/go-control-plane/envoy/config/transport_socket/tap/v2alpha\362\230\376\217\005+\022)envoy.extensions.transport_sockets.tap.v3\272\200\310\321\006\004\010\001\020\001'
  _TAP.fields_by_name['common_config']._options = None
  _TAP.fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TAP.fields_by_name['transport_socket']._options = None
  _TAP.fields_by_name['transport_socket']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_TAP']._serialized_start=263
  _globals['_TAP']._serialized_end=429
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/tap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.tap.v2alpha import common_pb2 as envoy_dot_service_dot_tap_dot_v2alpha_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65nvoy/admin/v2alpha/tap.proto\x12\x13\x65nvoy.admin.v2alpha\x1a&envoy/service/tap/v2alpha/common.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"l\n\nTapRequest\x12\x1a\n\tconfig_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x42\n\ntap_config\x18\x02 \x01(\x0b\x32$.envoy.service.tap.v2alpha.TapConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42s\n!io.envoyproxy.envoy.admin.v2alphaB\x08TapProtoP\x01Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v2alpha.tap_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.envoyproxy.envoy.admin.v2alphaB\010TapProtoP\001Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\272\200\310\321\006\002\020\001'
  _TAPREQUEST.fields_by_name['config_id']._options = None
  _TAPREQUEST.fields_by_name['config_id']._serialized_options = b'\372B\004r\002 \001'
  _TAPREQUEST.fields_by_name['tap_config']._options = None
  _TAPREQUEST.fields_by_name['tap_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_TAPREQUEST']._serialized_start=150
  _globals['_TAPREQUEST']._serialized_end=258
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v2alpha/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/data/tap/v2alpha/common.proto\x12\x16\x65nvoy.data.tap.v2alpha\x1a\x1dudpa/annotations/status.proto\"O\n\x04\x42ody\x12\x12\n\x08\x61s_bytes\x18\x01 \x01(\x0cH\x00\x12\x13\n\tas_string\x18\x02 \x01(\tH\x00\x12\x11\n\ttruncated\x18\x03 \x01(\x08\x42\x0b\n\tbody_typeB|\n$io.envoyproxy.envoy.data.tap.v2alphaB\x0b\x43ommonProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/data/tap/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.tap.v2alpha.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.envoyproxy.envoy.data.tap.v2alphaB\013CommonProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/data/tap/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_BODY']._serialized_start=94
  _globals['_BODY']._serialized_end=173
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1beta1/value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#google/api/expr/v1beta1/value.proto\x12\x17google.api.expr.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xbd\x03\n\x05Value\x12\x30\n\nnull_value\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x15\n\x0bint64_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0cuint64_value\x18\x04 \x01(\x04H\x00\x12\x16\n\x0c\x64ouble_value\x18\x05 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x06 \x01(\tH\x00\x12\x15\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00\x12\x38\n\nenum_value\x18\t \x01(\x0b\x32\".google.api.expr.v1beta1.EnumValueH\x00\x12,\n\x0cobject_value\x18\n \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x36\n\tmap_value\x18\x0b \x01(\x0b\x32!.google.api.expr.v1beta1.MapValueH\x00\x12\x38\n\nlist_value\x18\x0c \x01(\x0b\x32\".google.api.expr.v1beta1.ListValueH\x00\x12\x14\n\ntype_value\x18\x0f \x01(\tH\x00\x42\x06\n\x04kind\"(\n\tEnumValue\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05\";\n\tListValue\x12.\n\x06values\x18\x01 \x03(\x0b\x32\x1e.google.api.expr.v1beta1.Value\"\xa9\x01\n\x08MapValue\x12\x38\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\'.google.api.expr.v1beta1.MapValue.Entry\x1a\x63\n\x05\x45ntry\x12+\n\x03key\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1beta1.Value\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1beta1.ValueBk\n\x1b\x63om.google.api.expr.v1beta1B\nValueProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1beta1.value_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.google.api.expr.v1beta1B\nValueProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001'
  _globals['_VALUE']._serialized_start=122
  _globals['_VALUE']._serialized_end=567
  _globals['_ENUMVALUE']._serialized_start=569
  _globals['_ENUMVALUE']._serialized_end=609
  _globals['_LISTVALUE']._serialized_start=611
  _globals['_LISTVALUE']._serialized_end=670
  _globals['_MAPVALUE']._serialized_start=673
  _globals['_MAPVALUE']._serialized_end=842
  _globals['_MAPVALUE_ENTRY']._serialized_start=743
  _globals['_MAPVALUE_ENTRY']._serialized_end=842
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/accesslog/v2/als.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.data.accesslog.v2 import accesslog_pb2 as envoy_dot_data_dot_accesslog_dot_v2_dot_accesslog__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/service/accesslog/v2/als.proto\x12\x1a\x65nvoy.service.accesslog.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\'envoy/data/accesslog/v2/accesslog.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x1a\n\x18StreamAccessLogsResponse\"\xd9\x04\n\x17StreamAccessLogsMessage\x12R\n\nidentifier\x18\x01 \x01(\x0b\x32>.envoy.service.accesslog.v2.StreamAccessLogsMessage.Identifier\x12]\n\thttp_logs\x18\x02 \x01(\x0b\x32H.envoy.service.accesslog.v2.StreamAccessLogsMessage.HTTPAccessLogEntriesH\x00\x12[\n\x08tcp_logs\x18\x03 \x01(\x0b\x32G.envoy.service.accesslog.v2.StreamAccessLogsMessage.TCPAccessLogEntriesH\x00\x1aX\n\nIdentifier\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x08log_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x1a`\n\x14HTTPAccessLogEntries\x12H\n\tlog_entry\x18\x01 \x03(\x0b\x32+.envoy.data.accesslog.v2.HTTPAccessLogEntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a^\n\x13TCPAccessLogEntries\x12G\n\tlog_entry\x18\x01 \x03(\x0b\x32*.envoy.data.accesslog.v2.TCPAccessLogEntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\x12\n\x0blog_entries\x12\x03\xf8\x42\x01\x32\x96\x01\n\x10\x41\x63\x63\x65ssLogService\x12\x81\x01\n\x10StreamAccessLogs\x12\x33.envoy.service.accesslog.v2.StreamAccessLogsMessage\x1a\x34.envoy.service.accesslog.v2.StreamAccessLogsResponse\"\x00(\x01\x42\x8d\x01\n(io.envoyproxy.envoy.service.accesslog.v2B\x08\x41lsProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/service/accesslog/v2;accesslogv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.accesslog.v2.als_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.service.accesslog.v2B\010AlsProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/service/accesslog/v2;accesslogv2\272\200\310\321\006\002\020\001'
  _STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['node']._options = None
  _STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['node']._serialized_options = b'\372B\005\212\001\002\020\001'
  _STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['log_name']._options = None
  _STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['log_name']._serialized_options = b'\372B\004r\002 \001'
  _STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES.fields_by_name['log_entry']._options = None
  _STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES.fields_by_name['log_entry']._serialized_options = b'\372B\005\222\001\002\010\001'
  _STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES.fields_by_name['log_entry']._options = None
  _STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES.fields_by_name['log_entry']._serialized_options = b'\372B\005\222\001\002\010\001'
  _STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries']._options = None
  _STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries']._serialized_options = b'\370B\001'
  _globals['_STREAMACCESSLOGSRESPONSE']._serialized_start=195
  _globals['_STREAMACCESSLOGSRESPONSE']._serialized_end=221
  _globals['_STREAMACCESSLOGSMESSAGE']._serialized_start=224
  _globals['_STREAMACCESSLOGSMESSAGE']._serialized_end=825
  _globals['_STREAMACCESSLOGSMESSAGE_IDENTIFIER']._serialized_start=523
  _globals['_STREAMACCESSLOGSMESSAGE_IDENTIFIER']._serialized_end=611
  _globals['_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES']._serialized_start=613
  _globals['_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES']._serialized_end=709
  _globals['_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES']._serialized_start=711
  _globals['_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES']._serialized_end=805
  _globals['_ACCESSLOGSERVICE']._serialized_start=828
  _globals['_ACCESSLOGSERVICE']._serialized_end=978
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/quic/server_preferred_address/v3/fixed_server_preferred_address_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n]envoy/extensions/quic/server_preferred_address/v3/fixed_server_preferred_address_config.proto\x12\x31\x65nvoy.extensions.quic.server_preferred_address.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1dudpa/annotations/status.proto\"\xd6\x03\n!FixedServerPreferredAddressConfig\x12\x14\n\x0cipv4_address\x18\x01 \x01(\t\x12}\n\x0bipv4_config\x18\x03 \x01(\x0b\x32h.envoy.extensions.quic.server_preferred_address.v3.FixedServerPreferredAddressConfig.AddressFamilyConfig\x12\x14\n\x0cipv6_address\x18\x02 \x01(\t\x12}\n\x0bipv6_config\x18\x04 \x01(\x0b\x32h.envoy.extensions.quic.server_preferred_address.v3.FixedServerPreferredAddressConfig.AddressFamilyConfig\x1a\x86\x01\n\x13\x41\x64\x64ressFamilyConfig\x12\x34\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32#.envoy.config.core.v3.SocketAddress\x12\x39\n\x0c\x64nat_address\x18\x02 \x01(\x0b\x32#.envoy.config.core.v3.SocketAddressB\xe8\x01\n?io.envoyproxy.envoy.extensions.quic.server_preferred_address.v3B&FixedServerPreferredAddressConfigProtoP\x01Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/quic/server_preferred_address/v3;server_preferred_addressv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.quic.server_preferred_address.v3.fixed_server_preferred_address_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.extensions.quic.server_preferred_address.v3B&FixedServerPreferredAddressConfigProtoP\001Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/quic/server_preferred_address/v3;server_preferred_addressv3\272\200\310\321\006\002\020\002'
  _globals['_FIXEDSERVERPREFERREDADDRESSCONFIG']._serialized_start=216
  _globals['_FIXEDSERVERPREFERREDADDRESSCONFIG']._serialized_end=686
  _globals['_FIXEDSERVERPREFERREDADDRESSCONFIG_ADDRESSFAMILYCONFIG']._serialized_start=552
  _globals['_FIXEDSERVERPREFERREDADDRESSCONFIG_ADDRESSFAMILYCONFIG']._serialized_end=686
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/lds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from envoy.api.v2 import listener_pb2 as envoy_dot_api_dot_v2_dot_listener__pb2

from envoy.api.v2.listener_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x65nvoy/api/v2/lds.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x1b\x65nvoy/api/v2/listener.proto\"\n\n\x08LdsDummy2\xed\x02\n\x18ListenerDiscoveryService\x12\x61\n\x0e\x44\x65ltaListeners\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12X\n\x0fStreamListeners\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12u\n\x0e\x46\x65tchListeners\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v2/discovery:listeners:\x01*\x1a\x1d\x8a\xa4\x96\xf3\x07\x17\n\x15\x65nvoy.api.v2.ListenerB\x8c\x01\n\x1aio.envoyproxy.envoy.api.v2B\x08LdsProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\xf2\x98\xfe\x8f\x05\x1b\x12\x19\x65nvoy.service.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.lds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032io.envoyproxy.envoy.api.v2B\010LdsProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\362\230\376\217\005\033\022\031envoy.service.listener.v3\272\200\310\321\006\002\020\001'
  _LISTENERDISCOVERYSERVICE._options = None
  _LISTENERDISCOVERYSERVICE._serialized_options = b'\212\244\226\363\007\027\n\025envoy.api.v2.Listener'
  _LISTENERDISCOVERYSERVICE.methods_by_name['FetchListeners']._options = None
  _LISTENERDISCOVERYSERVICE.methods_by_name['FetchListeners']._serialized_options = b'\202\323\344\223\002\034\"\027/v2/discovery:listeners:\001*'
  _globals['_LDSDUMMY']._serialized_start=226
  _globals['_LDSDUMMY']._serialized_end=236
  _globals['_LISTENERDISCOVERYSERVICE']._serialized_start=239
  _globals['_LISTENERDISCOVERYSERVICE']._serialized_end=604
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/grpc_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/api/v2/core/grpc_service.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x8f\x12\n\x0bGrpcService\x12>\n\nenvoy_grpc\x18\x01 \x01(\x0b\x32(.envoy.api.v2.core.GrpcService.EnvoyGrpcH\x00\x12@\n\x0bgoogle_grpc\x18\x02 \x01(\x0b\x32).envoy.api.v2.core.GrpcService.GoogleGrpcH\x00\x12*\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x10initial_metadata\x18\x05 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\x1a*\n\tEnvoyGrpc\x12\x1d\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x1a\xcc\x0f\n\nGoogleGrpc\x12\x1b\n\ntarget_uri\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12Y\n\x13\x63hannel_credentials\x18\x02 \x01(\x0b\x32<.envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials\x12S\n\x10\x63\x61ll_credentials\x18\x03 \x03(\x0b\x32\x39.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials\x12\x1c\n\x0bstat_prefix\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12 \n\x18\x63redentials_factory_name\x18\x05 \x01(\t\x12\'\n\x06\x63onfig\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x1a\xb2\x01\n\x0eSslCredentials\x12\x31\n\nroot_certs\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12:\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x31\n\ncert_chain\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x1a\x18\n\x16GoogleLocalCredentials\x1a\x97\x02\n\x12\x43hannelCredentials\x12S\n\x0fssl_credentials\x18\x01 \x01(\x0b\x32\x38.envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentialsH\x00\x12\x30\n\x0egoogle_default\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12]\n\x11local_credentials\x18\x03 \x01(\x0b\x32@.envoy.api.v2.core.GrpcService.GoogleGrpc.GoogleLocalCredentialsH\x00\x42\x1b\n\x14\x63redential_specifier\x12\x03\xf8\x42\x01\x1a\x9e\t\n\x0f\x43\x61llCredentials\x12\x16\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tH\x00\x12\x37\n\x15google_compute_engine\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x1e\n\x14google_refresh_token\x18\x03 \x01(\tH\x00\x12\x82\x01\n\x1aservice_account_jwt_access\x18\x04 \x01(\x0b\x32\\.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentialsH\x00\x12\x64\n\ngoogle_iam\x18\x05 \x01(\x0b\x32N.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentialsH\x00\x12n\n\x0b\x66rom_plugin\x18\x06 \x01(\x0b\x32W.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPluginH\x00\x12[\n\x0bsts_service\x18\x07 \x01(\x0b\x32\x44.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsServiceH\x00\x1aV\n\"ServiceAccountJWTAccessCredentials\x12\x10\n\x08json_key\x18\x01 \x01(\t\x12\x1e\n\x16token_lifetime_seconds\x18\x02 \x01(\x04\x1aO\n\x14GoogleIAMCredentials\x12\x1b\n\x13\x61uthorization_token\x18\x01 \x01(\t\x12\x1a\n\x12\x61uthority_selector\x18\x02 \x01(\t\x1a\x99\x01\n\x1dMetadataCredentialsFromPlugin\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\x1a\xff\x01\n\nStsService\x12\"\n\x1atoken_exchange_service_uri\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x10\n\x08\x61udience\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x1c\n\x14requested_token_type\x18\x05 \x01(\t\x12#\n\x12subject_token_path\x18\x06 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12#\n\x12subject_token_type\x18\x07 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x18\n\x10\x61\x63tor_token_path\x18\x08 \x01(\t\x12\x18\n\x10\x61\x63tor_token_type\x18\t \x01(\tB\x1b\n\x14\x63redential_specifier\x12\x03\xf8\x42\x01\x42\x17\n\x10target_specifier\x12\x03\xf8\x42\x01J\x04\x08\x04\x10\x05\x42\x93\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x10GrpcServiceProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.grpc_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\020GrpcServiceProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _GRPCSERVICE_ENVOYGRPC.fields_by_name['cluster_name']._options = None
  _GRPCSERVICE_ENVOYGRPC.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002 \001'
  _GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['private_key']._options = None
  _GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['private_key']._serialized_options = b'\270\267\213\244\002\001'
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']._serialized_options = b'\370B\001'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['config']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['config']._serialized_options = b'\030\001'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_path']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_path']._serialized_options = b'\372B\004r\002 \001'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_type']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_type']._serialized_options = b'\372B\004r\002 \001'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']._serialized_options = b'\370B\001'
  _GRPCSERVICE_GOOGLEGRPC.fields_by_name['target_uri']._options = None
  _GRPCSERVICE_GOOGLEGRPC.fields_by_name['target_uri']._serialized_options = b'\372B\004r\002 \001'
  _GRPCSERVICE_GOOGLEGRPC.fields_by_name['stat_prefix']._options = None
  _GRPCSERVICE_GOOGLEGRPC.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _GRPCSERVICE.oneofs_by_name['target_specifier']._options = None
  _GRPCSERVICE.oneofs_by_name['target_specifier']._serialized_options = b'\370B\001'
  _globals['_GRPCSERVICE']._serialized_start=330
  _globals['_GRPCSERVICE']._serialized_end=2649
  _globals['_GRPCSERVICE_ENVOYGRPC']._serialized_start=577
  _globals['_GRPCSERVICE_ENVOYGRPC']._serialized_end=619
  _globals['_GRPCSERVICE_GOOGLEGRPC']._serialized_start=622
  _globals['_GRPCSERVICE_GOOGLEGRPC']._serialized_end=2618
  _globals['_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS']._serialized_start=947
  _globals['_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS']._serialized_end=1125
  _globals['_GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS']._serialized_start=1127
  _globals['_GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS']._serialized_end=1151
  _globals['_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS']._serialized_start=1154
  _globals['_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS']._serialized_end=1433
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS']._serialized_start=1436
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS']._serialized_end=2618
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS']._serialized_start=2008
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS']._serialized_end=2094
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS']._serialized_start=2096
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS']._serialized_end=2175
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN']._serialized_start=2178
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN']._serialized_end=2331
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE']._serialized_start=2334
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE']._serialized_end=2589
# @@protoc_insertion_point(module_scope)
